@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this package.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this package.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -125,7 +125,7 @@ version (void)
            "Copyright (C) 2000-2009 Martin Grabmueller,"
            " Stefan Jahn, Raimund Jacob, Andreas Rottmann\n"
            "License GPLv3+: GNU GPL version 3 or later"
-           " <http://gnu.org/licenses/gpl.html>\n"
+           " <https://gnu.org/licenses/gpl.html>\n"
            "This is free software: you are free"
            " to change and redistribute it.\n"
            "There is NO WARRANTY, to the extent permitted by law.\n",
@@ -153,7 +153,7 @@ longname (char letter)
 #endif  /* !deifned HAVE_GETOPT_LONG */
 
 #define AB(blurb,uri)    blurb ": <" uri ">\n"
-#define GNU(blurb,rest)  AB (blurb, "http://www.gnu.org/" rest)
+#define GNU(blurb,rest)  AB (blurb, "https://www.gnu.org/" rest)
 
 #define BUGME                                           \
   ("\n"                                                 \
